import numpy as np


# ---------------------------------------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------------------------------------
def coth(k, H, key):
    # key = 0   -> coth 
    # key = 1   -> tanh
    
    ct = np.zeros(len(k))
    for i in range(len(k)):
        if k[i]*H > 5:
            ct[i] = 1
        else:
            ct[i] = (np.exp(k[i]*H) + np.exp(-1*k[i]*H))/(np.exp(k[i]*H)-np.exp(-1*k[i]*H))
    
    
    if key == 1:
        ct = 1/ct
        
    return ct


# ---------------------------------------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------------------------------------
def ac_dispersion(rho_ice, rho_water, H, h, E, nu, fe, t, eq):

    # extracting frequency-wavenumber of air-coupled flexural wave, given a thickness
    freq  = np.linspace(-fe/2,fe/2,len(t)) 
    idx_freq = np.arange(int((len(t)-1)/2)+1,len(t), 1)  
    freq  = freq[idx_freq]
    #h = np.arange(.1, 1, .01)
    
    g = 9.81;
    D = E*pow(h,3)/(12*(1-nu**2))
    
    # wavelengths assumed btw 1-5000 m,
    k = np.linspace(0.0012566621946798098, 6.283185307179586, 100000)
    
    omeg = 2*np.pi*freq
    wavk = np.zeros(len(omeg))
    
    if eq == 0: # first dispersion relation, based on coth
        ct = coth(k, H, 0) 
        for i in range(len(freq)):
            Z = pow(omeg[i], 2)*(k*h*rho_ice/rho_water + ct) - D*pow(k, 5)/rho_water - g * k 
            
            argm = np.argmin(np.abs(Z))
            wavk[i] = k[argm]
            
    if eq == 1: # second dispersion relation, based on tanh
        ct = coth(k, H, 1) 
        for i in range(len(freq)):
            th = coth(k, H, 1)
            Z = pow(omeg[i], 2) - (D*pow(k, 4)/(rho_water*g) +1) * g*k*th
            
            argm = np.argmin(np.abs(Z))
            wavk[i] = k[argm]
    
    wavk = np.insert(wavk, 0,0)
    freq = np.insert(freq, 0,0)
    
    
    return freq, wavk
   
