#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Mar 12 10:52:50 2021

@author: moreaul
"""
from scipy import fft as fft
import numpy as np
import matplotlib.pyplot as plt


def coth(k, H, key):
    # key = 0   -> coth 
    # key = 1   -> tanh
    
    ct = np.zeros(len(k))
    for i in range(len(k)):
        if k[i]*H > 5:
            ct[i] = 1
        else:
            ct[i] = (np.exp(k[i]*H) + np.exp(-1*k[i]*H))/(np.exp(k[i]*H)-np.exp(-1*k[i]*H))
    
    
    if key == 1:
        ct = 1/ct
        
    return ct


def wavenumbers_romeyn(rho_ice, rho_water, H, h, E, nu, fe, t, eq):

    # extracting frequency-wavenumber of air-coupled flexural wave, given a thickness
    freq  = np.linspace(-fe/2,fe/2,len(t)) 
    idx_freq = np.arange(int((len(t)-1)/2)+1,len(t), 1)  
    freq  = freq[idx_freq]
    #h = np.arange(.1, 1, .01)
    
    g = 9.81;
    D = E*pow(h,3)/(12*(1-nu**2))
    
    # wavelengths assumed btw 1-5000 m,
    k = np.linspace(0.0012566621946798098, 6.283185307179586, 100000)
    
    omeg = 2*np.pi*freq
    wavk = np.zeros(len(omeg))
    
    if eq == 0: # first dispersion relation, based on coth
        ct = coth(k, H, 0) 
        for i in range(len(freq)):
            Z = pow(omeg[i], 2)*(k*h*rho_ice/rho_water + ct) - D*pow(k, 5)/rho_water - g * k 
            
            argm = np.argmin(np.abs(Z))
            wavk[i] = k[argm]
            
    if eq == 1: # second dispersion relation, based on tanh
        ct = coth(k, H, 1) 
        for i in range(len(freq)):
            th = coth(k, H, 1)
            Z = pow(omeg[i], 2) - (D*pow(k, 4)/(rho_water*g) +1) * g*k*th
            
            argm = np.argmin(np.abs(Z))
            wavk[i] = k[argm]
    
    wavk = np.insert(wavk, 0,0)
    freq = np.insert(freq, 0,0)
    
    
    return freq, wavk



def wavenumbers_stein( rho_ice, h, E, nu, fe,t,c_w,rho_w):
    
    freq  = np.linspace(-fe/2,fe/2,len(t)) 
    idx_freq = np.arange(int((len(t)-1)/2)+1,len(t), 1)  
    freq  = freq[idx_freq]

    
    
    g = 9.81;
    G = E/(2*(1+nu));
    cS0 = np.sqrt(E/(rho_ice*(1-nu**2)));
    cSH0 = np.sqrt(G/rho_ice);
    D = E*pow(h,3)/(12*(1-nu**2));
    
    
    
    
    k = np.linspace(1e-12,5,100000)
    
    idx_zero = np.zeros(len(freq)) 
    flag = 0
    for kf in range(len(freq)):
        omeg = 2*np.pi*freq[kf]
        if omeg == 0:
            flag = 1;
            idx_flag = kf;
        else:
            cph = omeg/k
            
            func = rho_w/D*(g-omeg/np.lib.scimath.sqrt((1/cph)**2 - (1/c_w)**2  )) - h*omeg**2*rho_w/D + pow(omeg/cph,4)
            func[func.imag != 0] = -1
            func = func.real
            idx_zero[kf] = (np.where(np.diff(np.signbit(func)))[0])
            
    idx_zero = idx_zero.astype(int)        
    k_QS =  k[idx_zero]       
    if flag:
        k_QS[idx_flag] = 0
        
    k_QS0 = 2*np.pi*freq/cS0
    k_SH0 = 2*np.pi*freq/cSH0
            
    
    
    cph = 2*np.pi*freq/k_QS

    k_QS = np.insert(k_QS, 0,0)
    k_QS0 = np.insert(k_QS0, 0,0)
    k_SH0 = np.insert(k_SH0, 0,0)


    cphQS = np.insert(cph, 0,0)
    freq = np.insert(freq, 0,0)

    
    return freq,k_QS, k_QS0, k_SH0, cphQS



def propag_dispersive_wave_1D(t,signal,x,cph): 
    if not isinstance(x, list):
        x = x =[x]
    
    Nx = len(x)
    Nt = len(t)
    
    
    fe = 1/(t[1]-t[0])
    freq = np.linspace(-fe/2,fe/2,Nt)
    spect = np.fft.fftshift(np.fft.fft(signal))
    
    #plt.plot(freq,abs(spect))

    
    data = np.zeros((Nx, Nt), dtype=float) 
    idx = np.concatenate([np.arange(0, int((len(t)-1)/2), 1), np.arange(int((len(t)-1)/2+1),len(t), 1) ])
    
    for k in range(Nx):
        cpt = 0
        signal = 0 
        
        for i in idx:
            omeg = 2*np.pi*freq[i]
            delay = x[k]/cph[i]
            sinus = np.exp(1j*(omeg*(t-delay)))
            signal = signal + sinus*(spect[i])
            cpt = cpt+1;

        
        signal = signal/cpt   
        data[k,:] = np.real(signal)
    
    
    return data










