#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 17 11:08:30 2021

@author: moreaul
"""
import numpy as np
import matplotlib.pyplot as plt
import mcmc_iqk
import matplotlib
    
def plot_mcmc(iter,data,data_scalogram,t,pulse,cph,fe,hhh,RMS_accepted,X,stations,method,path2save,savefig):

    
    
    I = np.argmin(RMS_accepted[0:iter])
    print('iter #' + str(iter) + ', RMS is minimal at iteration #' + str(I))
    
    synthetics = mcmc_iqk.synthetics.synthetics(stations,X[:,I],t,pulse,cph[np.abs(hhh - X[0,I]).argmin()],plot=0)
        
    cost,corr_sign  = mcmc_iqk.cost_function.cost_function(data_scalogram,data,synthetics,fe,method)    
    
    fig4, ax4 = plt.subplots(1,4, figsize=(15, 3), facecolor='w', edgecolor='k')
    fig4.subplots_adjust(hspace = .5, wspace=.5)
    ax4[0].plot(X[0,0:iter],'k',lw=0.75); ax4[0].set_title('thickness (m) VS iteration')
    ax4[1].plot(X[1,0:iter],'k',lw=0.75); ax4[1].set_title('latitude VS iteration')
    ax4[2].plot(X[2,0:iter],'k',lw=0.75); ax4[2].set_title('longitude VS iteration')
    ax4[3].plot(X[3,0:iter],'k',lw=0.75); ax4[3].set_title('phase shift (s) VS iteration')
    
    fig5, ax5 = plt.subplots(1,1, figsize=(7,3), facecolor='w', edgecolor='k')
    ax5.plot(RMS_accepted[0:iter],'k',lw=0.75); ax5.set_title('RMS VS iteration #')
    
    fig6, ax6 = plt.subplots(1,1, figsize=(10,5), facecolor='w', edgecolor='k')
    for ista in range(stations.shape[0]):        
        ax6.plot(t,data[ista]/np.amax(data[ista])+ista*2,'k',lw=0.5)          
        ax6.plot(t,corr_sign[ista]*synthetics[ista]+ista*2,'b--',lw=0.75)
        ax6.set_title(' data (k) VS synthetics (b--) for h = ' + str( "{:.2f}".format(X[0,I])) + ', RMS = ' + str( "{:.3f}".format(RMS_accepted[I])))        
            
            
    if savefig:        
        fig4.savefig(path2save+'paramters.png')
        fig5.savefig(path2save+'RMS.png')
        fig6.savefig(path2save+'waveforms.png')
        
        
                
    
    plt.close('all')    
    #plt.show()
    
    
   
   
