#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Mar 15 16:54:15 2021

@author: moreaul
"""
import numpy as np
import h5py 
import matplotlib.pyplot as plt
from scipy.signal import butter, filtfilt



def read_data(path2icqks,stations,sta_cluster,cluster,iqk,fmin,fmax,fe,plot):
    name_iqk_file = 'iqks_IWG' + '_' + f'{sta_cluster:02d}' + '_cluster'+ f'{cluster:02d}' + '_with_dates.hdf5'
    

    dataset = []
    data_spect = []
    fc = []
    b, a = butter(3, [fmin/(fe/2), fmax/(fe/2)], btype='band')
    
    
    for ista in range(stations.shape[0]):
        staname = str(int(stations[ista,0]))
        #print(staname)
        trace = 'traceZ'
    
        with h5py.File(path2icqks + name_iqk_file , "r") as f:
            iqk_time = list(f.keys())[iqk]
            G1=f.get(iqk_time)
            #print(iqk_time)
            G2 = G1.get(staname)
            tmp = np.array(G2.get(trace))

        tmp = filtfilt(b, a, tmp[0])
        dataset.append(tmp)
        
    
    Nt = len(tmp)   
    
    if Nt % 2 == 0:
        #print('Nt is even')
        Nt = Nt-1
        for ista in range(stations.shape[0]):   
            dataset[ista]=dataset[ista][:-1]
            
    

    freq  = np.linspace(0,fe,Nt)    
    for ista in range(stations.shape[0]):               
        spect = np.fft.fft(dataset[ista])       
        data_spect.append(spect)
        fc.append(freq[np.argmax(abs(spect))])

        

        
    if plot:   
        fig0, axs0 = plt.subplots(1,1, figsize=(10,6), facecolor='w', edgecolor='k')
        for ista in range(stations.shape[0]):
            plt.plot(np.arange(0,Nt/fe,1/fe),dataset[ista]/np.amax(dataset[ista])+ista*2,'k')
            plt.xlabel('time in icequake (s)')
            plt.ylabel('icequakes recordings (normalized max)')
            plt.title('icequakes recorded at stations')
        plt.show()

    return dataset, data_spect, fc, iqk_time
    
  









    
    